@@ -6,7 +6,9 @@
 """
 from __future__ import absolute_import
 
+from . import cpc
 from . import cuahsi
 from . import ncdc
+from . import usace
 from . import usgs
 from . import util
